/*
 * Guifications - The end all, be all, toaster popup plugin
 * Copyright (C) 2003-2004 Gary Kramlich
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef GF_FILE_H
#define GF_FILE_H

#include <glib.h>

G_BEGIN_DECLS

gboolean gf_file_copy_file(const gchar *source, const gchar *dest);
gboolean gf_file_copy_directory(const gchar *source, const gchar *destination);
void gf_file_remove_dir(const gchar *directory);
gint gf_file_access(const gchar *filename, gint mode);

G_END_DECLS

#endif /* GF_FILE_H */
